import { defineStore } from 'pinia'
import * as api from '@/api'
import { PageNumberPaginationParameters } from '@/api'
import { errorParser } from '@/helpers'
import { PageNumberPagination, UUID } from '@/types'
import { OAuthCredentials, OAuthProvider, OAuthStatus } from '@/types/oauth'
import { useNotificationStore } from '.'

interface State {
  providers: OAuthProvider[] | null
  credentials: PageNumberPagination<OAuthCredentials> | null
}

interface CredentialsListParameters extends PageNumberPaginationParameters {
  status?: OAuthStatus
}

export const useOAuthStore = defineStore('oauth', {
  state: (): State => ({
    providers: null,
    credentials: null
  }),
  actions: {
    async listProviders () {
      try {
        this.providers = await api.listProviders()
      } catch (err) {
        this.providers = null
        useNotificationStore().notify({ type: 'error', text: errorParser(err) })
      }
    },

    async listCredentials (payload: CredentialsListParameters = {}) {
      try {
        this.credentials = await api.listCredentials(payload)
      } catch (err) {
        this.credentials = null
        useNotificationStore().notify({ type: 'error', text: errorParser(err) })
      }
    },

    async deleteCredentials (id: UUID) {
      try {
        await api.deleteCredentials(id)
      } catch (err) {
        useNotificationStore().notify({ type: 'error', text: errorParser(err) })
      }
    }
  }
})